==> knative-annotations-4.0.0-sources.jar: io/dekorate/knative/config/TrafficFluent.java <==
package io.dekorate.knative.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TrafficFluent<A extends TrafficFluent<A>> extends BaseFluent<A>{
  public TrafficFluent() {
  }
  public TrafficFluent(Traffic instance) {
    instance = (instance != null ? instance : new Traffic());

    if (instance != null) {
      this.withTag(instance.getTag());
      this.withRevisionName(instance.getRevisionName());
      this.withLatestRevision(instance.getLatestRevision());
      this.withPercentage(instance.getPercentage());
    }
  }
  private String tag;
  private String revisionName;
  private Boolean latestRevision;
  private Integer percentage;
  public String getTag() {
    return this.tag;
  }
  public A withTag(String tag) {
    this.tag=tag; return (A) this;
  }
  public boolean hasTag() {
    return this.tag != null;
  }
  public String getRevisionName() {
    return this.revisionName;
  }
  public A withRevisionName(String revisionName) {
    this.revisionName=revisionName; return (A) this;
  }
  public boolean hasRevisionName() {
    return this.revisionName != null;
  }
  public Boolean getLatestRevision() {
    return this.latestRevision;
  }
  public A withLatestRevision(Boolean latestRevision) {
    this.latestRevision=latestRevision; return (A) this;
  }
  public boolean hasLatestRevision() {
    return this.latestRevision != null;
  }
  public Integer getPercentage() {
    return this.percentage;
  }
  public A withPercentage(Integer percentage) {
    this.percentage=percentage; return (A) this;
  }
  public boolean hasPercentage() {
    return this.percentage != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TrafficFluent that = (TrafficFluent) o;
    if (!java.util.Objects.equals(tag, that.tag)) return false;

    if (!java.util.Objects.equals(revisionName, that.revisionName)) return false;

    if (!java.util.Objects.equals(latestRevision, that.latestRevision)) return false;

    if (!java.util.Objects.equals(percentage, that.percentage)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tag,  revisionName,  latestRevision,  percentage,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tag != null) { sb.append("tag:"); sb.append(tag + ","); }
    if (revisionName != null) { sb.append("revisionName:"); sb.append(revisionName + ","); }
    if (latestRevision != null) { sb.append("latestRevision:"); sb.append(latestRevision + ","); }
    if (percentage != null) { sb.append("percentage:"); sb.append(percentage); }
    sb.append("}");
    return sb.toString();
  }
  public A withLatestRevision() {
    return withLatestRevision(true);
  }
  
}

==> knative-annotations-4.1.4-sources.jar: io/dekorate/knative/config/TrafficFluent.java <==
package io.dekorate.knative.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TrafficFluent<A extends TrafficFluent<A>> extends BaseFluent<A>{
  public TrafficFluent() {
  }
  
  public TrafficFluent(Traffic instance) {
    this.copyInstance(instance);
  }
  private String tag;
  private String revisionName;
  private Boolean latestRevision;
  private Integer percentage;
  
  protected void copyInstance(Traffic instance) {
    instance = (instance != null ? instance : new Traffic());
    if (instance != null) {
          this.withTag(instance.getTag());
          this.withRevisionName(instance.getRevisionName());
          this.withLatestRevision(instance.getLatestRevision());
          this.withPercentage(instance.getPercentage());
        }
  }
  
  public String getTag() {
    return this.tag;
  }
  
  public A withTag(String tag) {
    this.tag = tag;
    return (A) this;
  }
  
  public boolean hasTag() {
    return this.tag != null;
  }
  
  public String getRevisionName() {
    return this.revisionName;
  }
  
  public A withRevisionName(String revisionName) {
    this.revisionName = revisionName;
    return (A) this;
  }
  
  public boolean hasRevisionName() {
    return this.revisionName != null;
  }
  
  public Boolean getLatestRevision() {
    return this.latestRevision;
  }
  
  public A withLatestRevision(Boolean latestRevision) {
    this.latestRevision = latestRevision;
    return (A) this;
  }
  
  public boolean hasLatestRevision() {
    return this.latestRevision != null;
  }
  
  public Integer getPercentage() {
    return this.percentage;
  }
  
  public A withPercentage(Integer percentage) {
    this.percentage = percentage;
    return (A) this;
  }
  
  public boolean hasPercentage() {
    return this.percentage != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TrafficFluent that = (TrafficFluent) o;
    if (!java.util.Objects.equals(tag, that.tag)) return false;
    if (!java.util.Objects.equals(revisionName, that.revisionName)) return false;
    if (!java.util.Objects.equals(latestRevision, that.latestRevision)) return false;
    if (!java.util.Objects.equals(percentage, that.percentage)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(tag,  revisionName,  latestRevision,  percentage,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tag != null) { sb.append("tag:"); sb.append(tag + ","); }
    if (revisionName != null) { sb.append("revisionName:"); sb.append(revisionName + ","); }
    if (latestRevision != null) { sb.append("latestRevision:"); sb.append(latestRevision + ","); }
    if (percentage != null) { sb.append("percentage:"); sb.append(percentage); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withLatestRevision() {
    return withLatestRevision(true);
  }
  

}
